'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function computeEndingArrowDirectionVector(endingAnchor) {
  switch (endingAnchor) {
    case 'left':
      return { arrowX: -1, arrowY: 0 };
    case 'right':
      return { arrowX: 1, arrowY: 0 };
    case 'top':
      return { arrowX: 0, arrowY: -1 };
    case 'bottom':
      return { arrowX: 0, arrowY: 1 };
    default:
      return { arrowX: 0, arrowY: 0 };
  }
}

function computeEndingPointAccordingToArrow(xEnd, yEnd, arrowLength, endingAnchor) {
  var _computeEndingArrowDi = computeEndingArrowDirectionVector(endingAnchor),
      arrowX = _computeEndingArrowDi.arrowX,
      arrowY = _computeEndingArrowDi.arrowY;

  var xe = xEnd + arrowX * arrowLength;
  var ye = yEnd + arrowY * arrowLength;

  return { xe: xe, ye: ye };
}

function computeStartingAnchorPosition(xs, ys, xe, ye, startingAnchor) {
  if (startingAnchor === 'top' || startingAnchor === 'bottom') {
    return {
      xa1: xs,
      ya1: ys + (ye - ys) / 2
    };
  }
  if (startingAnchor === 'left' || startingAnchor === 'right') {
    return {
      xa1: xs + (xe - xs) / 2,
      ya1: ys
    };
  }

  return { xa1: xs, ya1: ys };
}

function computeEndingAnchorPosition(xs, ys, xe, ye, endingAnchor) {
  if (endingAnchor === 'top' || endingAnchor === 'bottom') {
    return {
      xa2: xe,
      ya2: ye - (ye - ys) / 2
    };
  }
  if (endingAnchor === 'left' || endingAnchor === 'right') {
    return {
      xa2: xe - (xe - xs) / 2,
      ya2: ye
    };
  }

  return { xa2: xe, ya2: ye };
}

var SvgArrow = function SvgArrow(_ref) {
  var startingPoint = _ref.startingPoint,
      startingAnchor = _ref.startingAnchor,
      endingPoint = _ref.endingPoint,
      endingAnchor = _ref.endingAnchor,
      strokeColor = _ref.strokeColor,
      arrowLength = _ref.arrowLength;

  var actualArrowLength = arrowLength * 2;

  var xs = startingPoint.x;
  var ys = startingPoint.y;

  var _computeEndingPointAc = computeEndingPointAccordingToArrow(endingPoint.x, endingPoint.y, actualArrowLength, endingAnchor),
      xe = _computeEndingPointAc.xe,
      ye = _computeEndingPointAc.ye;

  var _computeStartingAncho = computeStartingAnchorPosition(xs, ys, xe, ye, startingAnchor),
      xa1 = _computeStartingAncho.xa1,
      ya1 = _computeStartingAncho.ya1;

  var _computeEndingAnchorP = computeEndingAnchorPosition(xs, ys, xe, ye, endingAnchor),
      xa2 = _computeEndingAnchorP.xa2,
      ya2 = _computeEndingAnchorP.ya2;

  var pathString = 'M' + xs + ',' + ys + ' ' + ('C' + xa1 + ',' + ya1 + ' ' + xa2 + ',' + ya2 + ' ') + (xe + ',' + ye);

  return _react2.default.createElement('path', {
    d: pathString,
    style: { fill: 'none', stroke: strokeColor, strokeWidth: 2 },
    markerEnd: 'url(#arrow)'
  });
};

var pointPropType = _propTypes2.default.shape({
  x: _propTypes2.default.number,
  y: _propTypes2.default.number
});

var anchorType = _propTypes2.default.oneOf(['top', 'bottom', 'left', 'right']);

SvgArrow.propTypes = {
  startingPoint: pointPropType,
  startingAnchor: anchorType,
  endingPoint: pointPropType,
  endingAnchor: anchorType,
  strokeColor: _propTypes2.default.string,
  arrowLength: _propTypes2.default.number
};

exports.default = SvgArrow;